@@ -92,7 +92,7 @@ class Train(object):
 
         self.cloud_service = cloud_service
         # self.url = "http://192.168.1.135:12020/upload_service/"
-        self.url = "https://rpa-vc-upload.ai-indeed.com/"
+        self.url = "https://rpa-vc-upload.ai-indeed.com/upload_service/"
 
         # nh:size of the lstm hidden state
         self.model = CRNN(imgH=self.short_size, nc=1, nclass=len(alphabet), nh=256)
@@ -251,6 +251,7 @@ class Train(object):
                                os.path.join(self.model_path,
                                             self.app_scenes + "_verification.pth"))
                     self.patient_epoch = 0
+                    self.val_best_acc = val_acc
                 else:
                     self.patient_epoch += 1
                 if self.val_best_acc > self.target_acc or self.patient_epoch > 30:
